
# Slot: default_weight


The edge weight to be used when the edge weight for a given edge in the edge file is None.

URI: [https://w3id.org/neat/ensmallenRunConfig__default_weight](https://w3id.org/neat/ensmallenRunConfig__default_weight)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Float](types/Float.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
